@@ -30,6 +30,7 @@ pub fn power_preference_from_env() -> Option<PowerPreference> {
         {
             Ok("low") => PowerPreference::LowPower,
             Ok("high") => PowerPreference::HighPerformance,
+            Ok("none") => PowerPreference::None,
             _ => return None,
         },
     )
@@ -37,18 +38,27 @@ pub fn power_preference_from_env() -> Option<PowerPreference> {
 
 /// Initialize the adapter obeying the WGPU_ADAPTER_NAME environment variable.
 #[cfg(not(target_arch = "wasm32"))]
-pub fn initialize_adapter_from_env(instance: &Instance, backend_bits: Backends) -> Option<Adapter> {
+pub fn initialize_adapter_from_env(
+    instance: &Instance,
+    compatible_surface: Option<&Surface>,
+) -> Option<Adapter> {
     let desired_adapter_name = std::env::var("WGPU_ADAPTER_NAME")
         .as_deref()
         .map(str::to_lowercase)
         .ok()?;
 
-    let adapters = instance.enumerate_adapters(backend_bits);
+    let adapters = instance.enumerate_adapters(Backends::all());
 
     let mut chosen_adapter = None;
     for adapter in adapters {
         let info = adapter.get_info();
 
+        if let Some(surface) = compatible_surface {
+            if !adapter.is_surface_supported(surface) {
+                continue;
+            }
+        }
+
         if info.name.to_lowercase().contains(&desired_adapter_name) {
             chosen_adapter = Some(adapter);
             break;
@@ -62,7 +72,7 @@ pub fn initialize_adapter_from_env(instance: &Instance, backend_bits: Backends)
 #[cfg(target_arch = "wasm32")]
 pub fn initialize_adapter_from_env(
     _instance: &Instance,
-    _backend_bits: Backends,
+    _compatible_surface: Option<&Surface>,
 ) -> Option<Adapter> {
     None
 }
@@ -70,10 +80,9 @@ pub fn initialize_adapter_from_env(
 /// Initialize the adapter obeying the WGPU_ADAPTER_NAME environment variable and if it doesn't exist fall back on a default adapter.
 pub async fn initialize_adapter_from_env_or_default(
     instance: &Instance,
-    backend_bits: wgt::Backends,
     compatible_surface: Option<&Surface>,
 ) -> Option<Adapter> {
-    match initialize_adapter_from_env(instance, backend_bits) {
+    match initialize_adapter_from_env(instance, compatible_surface) {
         Some(a) => Some(a),
         None => {
             instance
@@ -86,3 +95,42 @@ pub async fn initialize_adapter_from_env_or_default(
         }
     }
 }
+
+/// Choose which DX12 shader compiler to use from the environment variable `WGPU_DX12_COMPILER`.
+///
+/// Possible values are `dxc` and `fxc`. Case insensitive.
+pub fn dx12_shader_compiler_from_env() -> Option<wgt::Dx12Compiler> {
+    Some(
+        match std::env::var("WGPU_DX12_COMPILER")
+            .as_deref()
+            .map(str::to_lowercase)
+            .as_deref()
+        {
+            Ok("dxc") => wgt::Dx12Compiler::Dxc {
+                dxil_path: None,
+                dxc_path: None,
+            },
+            Ok("fxc") => wgt::Dx12Compiler::Fxc,
+            _ => return None,
+        },
+    )
+}
+
+/// Choose which minor OpenGL ES version to use from the environment variable `WGPU_GLES_MINOR_VERSION`.
+///
+/// Possible values are `0`, `1`, `2` or `automatic`. Case insensitive.
+pub fn gles_minor_version_from_env() -> Option<wgt::Gles3MinorVersion> {
+    Some(
+        match std::env::var("WGPU_GLES_MINOR_VERSION")
+            .as_deref()
+            .map(str::to_lowercase)
+            .as_deref()
+        {
+            Ok("automatic") => wgt::Gles3MinorVersion::Automatic,
+            Ok("0") => wgt::Gles3MinorVersion::Version0,
+            Ok("1") => wgt::Gles3MinorVersion::Version1,
+            Ok("2") => wgt::Gles3MinorVersion::Version2,
+            _ => return None,
+        },
+    )
+}
